==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/core/l10n/fi_FI.php <==
<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "Päättymispäivä on menneisyydessä.",
"Couldn't send mail to following users: %s " => "Sähköpostin lähetys seuraaville käyttäjille epäonnistui: %s",
"Turned on maintenance mode" => "Siirrytty ylläpitotilaan",
"Turned off maintenance mode" => "Ylläpitotila laitettu pois päältä",
"Updated database" => "Tietokanta ajan tasalla",
"Checked database schema update" => "Tarkistettu tietokannan skeemapäivitys",
"Disabled incompatible apps: %s" => "Yhteensopimattomat sovellukset poistettiin käytöstä: %s",
"No image or file provided" => "Kuvaa tai tiedostoa ei määritelty",
"Unknown filetype" => "Tuntematon tiedostotyyppi",
"Invalid image" => "Virhellinen kuva",
"No temporary profile picture available, try again" => "Väliaikaista profiilikuvaa ei ole käytettävissä, yritä uudelleen",
"No crop data provided" => "Puutteellinen tieto",
"Sunday" => "sunnuntai",
"Monday" => "maanantai",
"Tuesday" => "tiistai",
"Wednesday" => "keskiviikko",
"Thursday" => "torstai",
"Friday" => "perjantai",
"Saturday" => "lauantai",
"January" => "tammikuu",
"February" => "helmikuu",
"March" => "maaliskuu",
"April" => "huhtikuu",
"May" => "toukokuu",
"June" => "kesäkuu",
"July" => "heinäkuu",
"August" => "elokuu",
"September" => "syyskuu",
"October" => "lokakuu",
"November" => "marraskuu",
"December" => "joulukuu",
"Settings" => "Asetukset",
"File" => "Tiedosto",
"Folder" => "Kansio",
"Image" => "Kuva",
"Audio" => "Ääni",
"Saving..." => "Tallennetaan...",
"seconds ago" => "sekuntia sitten",
"_%n minute ago_::_%n minutes ago_" => array("%n minuutti sitten","%n minuuttia sitten"),
"_%n hour ago_::_%n hours ago_" => array("%n tunti sitten","%n tuntia sitten"),
"today" => "tänään",
"yesterday" => "eilen",
"_%n day ago_::_%n days ago_" => array("%n päivä sitten","%n päivää sitten"),
"last month" => "viime kuussa",
"_%n month ago_::_%n months ago_" => array("%n kuukausi sitten","%n kuukautta sitten"),
"last year" => "viime vuonna",
"years ago" => "vuotta sitten",
"I know what I'm doing" => "Tiedän mitä teen",
"Reset password" => "Palauta salasana",
"Password can not be changed. Please contact your administrator." => "Salasanan vaihtaminen ei onnistunut. Ota yhteys ylläpitäjään.",
"Yes" => "Kyllä",
"No" => "Ei",
"Choose" => "Valitse",
"Error loading file picker template: {error}" => "Virhe ladatessa tiedostopohjia: {error}",
"Ok" => "Ok",
"Error loading message template: {error}" => "Virhe ladatessa viestipohjaa: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} tiedoston ristiriita","{count} tiedoston ristiriita"),
"One file conflict" => "Yhden tiedoston ristiriita",
"New Files" => "Uudet tiedostot",
"Already existing files" => "Jo olemassa olevat tiedostot",
"Which files do you want to keep?" => "Mitkä tiedostot haluat säilyttää?",
"If you select both versions, the copied file will have a number added to its name." => "Jos valitset kummatkin versiot, kopioidun tiedoston nimeen lisätään numero.",
"Cancel" => "Peru",
"Continue" => "Jatka",
"(all selected)" => "(kaikki valittu)",
"({count} selected)" => "({count} valittu)",
"Error loading file exists template" => "Virhe ladatessa mallipohjaa",
"Very weak password" => "Erittäin heikko salasana",
"Weak password" => "Heikko salasana",
"So-so password" => "Kohtalainen salasana",
"Good password" => "Hyvä salasana",
"Strong password" => "Vahva salasana",
"Shared" => "Jaettu",
"Shared by {owner}" => "Jakanut {owner}",
"Shared with {recipients}" => "Jaettu henkilöiden {recipients} kanssa",
"Share" => "Jaa",
"Error" => "Virhe",
"Error while sharing" => "Virhe jaettaessa",
"Error while unsharing" => "Virhe jakoa peruttaessa",
"Error while changing permissions" => "Virhe oikeuksia muuttaessa",
"Shared with you and the group {group} by {owner}" => "Jaettu sinun ja ryhmän {group} kanssa käyttäjän {owner} toimesta",
"Shared with you by {owner}" => "Jaettu kanssasi käyttäjän {owner} toimesta",
"Share with user or group …" => "Jaa käyttäjän tai ryhmän kanssa…",
"Share link" => "Jaa linkki",
"The public link will expire no later than {days} days after it is created" => "Julkinen linkki vanhenee {days} päivän jälkeen sen luomisesta",
"By default the public link will expire after {days} days" => "Oletuksena julkinen linkki vanhenee {days} päivässä",
"Password protect" => "Suojaa salasanalla",
"Choose a password for the public link" => "Valitse salasana julkiselle linkille",
"Allow Public Upload" => "Salli julkinen lähetys",
"Email link to person" => "Lähetä linkki sähköpostitse",
"Send" => "Lähetä",
"Set expiration date" => "Aseta päättymispäivä",
"Expiration date" => "Päättymispäivä",
"Share via email:" => "Jaa sähköpostilla:",
"No people found" => "Henkilöitä ei löytynyt",
"group" => "ryhmä",
"Resharing is not allowed" => "Jakaminen uudelleen ei ole salittu",
"Shared in {item} with {user}" => "{item} on jaettu {user} kanssa",
"Unshare" => "Peru jakaminen",
"notify by email" => "ilmoita sähköpostitse",
"can share" => "jaa",
"can edit" => "voi muokata",
"access control" => "Pääsyn hallinta",
"create" => "luo",
"update" => "päivitä",
"delete" => "poista",
"Password protected" => "Salasanasuojattu",
"Error unsetting expiration date" => "Virhe purettaessa eräpäivää",
"Error setting expiration date" => "Virhe päättymispäivää asettaessa",
"Sending ..." => "Lähetetään...",
"Email sent" => "Sähköposti lähetetty",
"Warning" => "Varoitus",
"The object type is not specified." => "The object type is not specified.",
"Enter new" => "Kirjoita uusi",
"Delete" => "Poista",
"Add" => "Lisää",
"Edit tags" => "Muokkaa tunnisteita",
"Error loading dialog template: {error}" => "Virhe ladatessa keskustelupohja: {error}",
"No tags selected for deletion." => "Tunnisteita ei valittu poistettavaksi.",
"Updating {productName} to version {version}, this may take a while." => "Päivitetään {productName} versioon {version}, tämä saattaa kestää hetken.",
"Please reload the page." => "Päivitä sivu.",
"The update was unsuccessful." => "Päivitys epäonnistui.",
"The update was successful. Redirecting you to ownCloud now." => "Päivitys onnistui. Selain ohjautuu nyt ownCloudiisi.",
"%s password reset" => "%s salasanan nollaus",
"Use the following link to reset your password: {link}" => "Voit palauttaa salasanasi seuraavassa osoitteessa: {link}",
"You will receive a link to reset your password via Email." => "Saat sähköpostitse linkin nollataksesi salasanan.",
"Username" => "Käyttäjätunnus",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Tiedostosi on salattu. Jos et ole ottanut palautusavainta käyttöön, et voi käyttää tiedostojasi enää salasanan nollauksen jälkeen. Jos et ole varma mitä tehdä, ota yhteys ylläpitoon ennen kuin jatkat. Haluatko varmasti jatkaa?",
"Yes, I really want to reset my password now" => "Kyllä, haluan nollata salasanani nyt",
"Reset" => "Nollaa salasana",
"New password" => "Uusi salasana",
"New Password" => "Uusi salasana",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Mac OS X ei ole tuettu, joten %s ei toimi kunnolla tällä alustalla. Käytä omalla vastuulla!",
"For the best results, please consider using a GNU/Linux server instead." => "Käytä parhaan lopputuloksen saamiseksi GNU/Linux-palvelinta.",
"Personal" => "Henkilökohtainen",
"Users" => "Käyttäjät",
"Apps" => "Sovellukset",
"Admin" => "Ylläpito",
"Help" => "Ohje",
"Error loading tags" => "Virhe tunnisteita ladattaessa",
"Tag already exists" => "Tunniste on jo olemassa",
"Error deleting tag(s)" => "Virhe tunnisteita poistaessa",
"Error tagging" => "Tunnisteiden kirjoitusvirhe",
"Error untagging" => "Tunisteiden poisto virhe",
"Error favoriting" => "Suosituksen kirjoitusvirhe",
"Error unfavoriting" => "Suosituksen poisto virhe",
"Access forbidden" => "Pääsy estetty",
"Cloud not found" => "Pilveä ei löydy",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Hei sinä!\n\n%s jakoi kohteen %s kanssasi.\nTutustu siihen: %s\n\n",
"The share will expire on %s." => "Jakaminen päättyy %s.",
"Cheers!" => "Kippis!",
"Security Warning" => "Turvallisuusvaroitus",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "PHP-asennuksesi on haavoittuvainen NULL Byte -hyökkäykselle (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Päivitä PHP-asennus varmistaaksesi, että %s on turvallinen käyttää.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "Turvallista satunnaislukugeneraattoria ei ole käytettävissä, ota käyttöön PHP:n OpenSSL-laajennus",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Ilman turvallinen satunnaislukugeneraattori, hyökkääjä saattaa pystyä ennustamaan salasanan tunnuksineen ja ottaa tilisi.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Datakansiosi ja tiedostosi ovat mitä luultavimmin muiden saavutettavissa internetistä, koska .htaccess-tiedosto ei toimi.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "Lisätietoja palvelimen asetuksien määrittämisestä on saatavilla <a href=\"%s\" target=\"_blank\">dokumentaatiosta</a>.",
"Create an <strong>admin account</strong>" => "Luo <strong>ylläpitäjän tunnus</strong>",
"Password" => "Salasana",
"Storage & database" => "Tallennus ja tietokanta",
"Data folder" => "Datakansio",
"Configure the database" => "Muokkaa tietokantaa",
"Only %s is available." => "Vain %s on käytettävissä.",
"Database user" => "Tietokannan käyttäjä",
"Database password" => "Tietokannan salasana",
"Database name" => "Tietokannan nimi",
"Database tablespace" => "Tietokannan taulukkotila",
"Database host" => "Tietokantapalvelin",
"SQLite will be used as database. For larger installations we recommend to change this." => "SQLitea käytetään tietokantana. Laajoja asennuksia varten tämä asetus kannattaa muuttaa. ",
"Finish setup" => "Viimeistele asennus",
"Finishing …" => "Valmistellaan…",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "Tämä sovellus vaatii toimiakseen JavaScriptin käyttöä. <a href=\"http://enable-javascript.com/\" target=\"_blank\">Ota JavaScript käyttöön</a> ja päivitä tämä käyttöliittymä.",
"%s is available. Get more information on how to update." => "%s on saatavilla. Lue lisätietoja, miten päivitys asennetaan.",
"Log out" => "Kirjaudu ulos",
"Automatic logon rejected!" => "Automaattinen sisäänkirjautuminen hylättiin!",
"If you did not change your password recently, your account may be compromised!" => "Jos et vaihtanut salasanaasi äskettäin, tilisi saattaa olla murrettu.",
"Please change your password to secure your account again." => "Vaihda salasanasi suojataksesi tilisi uudelleen.",
"Server side authentication failed!" => "Palvelimen puoleinen tunnistautuminen epäonnistui!",
"Please contact your administrator." => "Ota yhteys ylläpitäjään.",
"Forgot your password? Reset it!" => "Unohditko salasanasi? Palauta se!",
"remember" => "muista",
"Log in" => "Kirjaudu sisään",
"Alternative Logins" => "Vaihtoehtoiset kirjautumiset",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Hei!<br><br>%s jakoi kanssasi kohteen <strong>%s</strong>.<br><a href=\"%s\">Tutustu siihen!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "Tämä ownCloud-asennus on parhaillaan single user -tilassa.",
"This means only administrators can use the instance." => "Se tarkoittaa, että vain ylläpitäjät voivat nyt käyttää tätä ownCloudia.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
"Thank you for your patience." => "Kiitos kärsivällisyydestäsi.",
"%s will be updated to version %s." => "%s päivitetään versioon %s.",
"The following apps will be disabled:" => "Seuraavat sovellukset poistetaan käytöstä:",
"The theme %s has been disabled." => "Teema %s on poistettu käytöstä.",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "Varmista ennen jatkamista, että tietokanta, asetuskansio ja datakansio on varmuuskopioitu.",
"Start update" => "Käynnistä päivitys",
"This ownCloud instance is currently being updated, which may take a while." => "Tätä ownCloud-asennusta päivitetään parhaillaan, siinä saattaa kestää hetki.",
"Please reload this page after a short time to continue using ownCloud." => "Päivitä tämä sivu hetken kuluttua jatkaaksesi ownCloudin käyttämistä.",
"File not found" => "Tiedostoa ei löytynyt",
"The specified document has not been found on the server." => "Määritettyä asiakirjaa ei löytynyt palvelimelta.",
"You can click here to return to %s." => "Napsauta tästä palataksesi %siin.",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/core/l10n/fi_FI.php <==
<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "Päättymispäivä on menneisyydessä.",
"Couldn't send mail to following users: %s " => "Sähköpostin lähetys seuraaville käyttäjille epäonnistui: %s",
"Turned on maintenance mode" => "Siirrytty ylläpitotilaan",
"Turned off maintenance mode" => "Ylläpitotila laitettu pois päältä",
"Updated database" => "Tietokanta ajan tasalla",
"Checked database schema update" => "Tarkistettu tietokannan skeemapäivitys",
"Disabled incompatible apps: %s" => "Yhteensopimattomat sovellukset poistettiin käytöstä: %s",
"No image or file provided" => "Kuvaa tai tiedostoa ei määritelty",
"Unknown filetype" => "Tuntematon tiedostotyyppi",
"Invalid image" => "Virhellinen kuva",
"No temporary profile picture available, try again" => "Väliaikaista profiilikuvaa ei ole käytettävissä, yritä uudelleen",
"No crop data provided" => "Puutteellinen tieto",
"Sunday" => "sunnuntai",
"Monday" => "maanantai",
"Tuesday" => "tiistai",
"Wednesday" => "keskiviikko",
"Thursday" => "torstai",
"Friday" => "perjantai",
"Saturday" => "lauantai",
"January" => "tammikuu",
"February" => "helmikuu",
"March" => "maaliskuu",
"April" => "huhtikuu",
"May" => "toukokuu",
"June" => "kesäkuu",
"July" => "heinäkuu",
"August" => "elokuu",
"September" => "syyskuu",
"October" => "lokakuu",
"November" => "marraskuu",
"December" => "joulukuu",
"Settings" => "Asetukset",
"File" => "Tiedosto",
"Folder" => "Kansio",
"Image" => "Kuva",
"Audio" => "Ääni",
"Saving..." => "Tallennetaan...",
"seconds ago" => "sekuntia sitten",
"_%n minute ago_::_%n minutes ago_" => array("%n minuutti sitten","%n minuuttia sitten"),
"_%n hour ago_::_%n hours ago_" => array("%n tunti sitten","%n tuntia sitten"),
"today" => "tänään",
"yesterday" => "eilen",
"_%n day ago_::_%n days ago_" => array("%n päivä sitten","%n päivää sitten"),
"last month" => "viime kuussa",
"_%n month ago_::_%n months ago_" => array("%n kuukausi sitten","%n kuukautta sitten"),
"last year" => "viime vuonna",
"years ago" => "vuotta sitten",
"I know what I'm doing" => "Tiedän mitä teen",
"Reset password" => "Palauta salasana",
"Password can not be changed. Please contact your administrator." => "Salasanan vaihtaminen ei onnistunut. Ota yhteys ylläpitäjään.",
"Yes" => "Kyllä",
"No" => "Ei",
"Choose" => "Valitse",
"Error loading file picker template: {error}" => "Virhe ladatessa tiedostopohjia: {error}",
"Ok" => "Ok",
"Error loading message template: {error}" => "Virhe ladatessa viestipohjaa: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} tiedoston ristiriita","{count} tiedoston ristiriita"),
"One file conflict" => "Yhden tiedoston ristiriita",
"New Files" => "Uudet tiedostot",
"Already existing files" => "Jo olemassa olevat tiedostot",
"Which files do you want to keep?" => "Mitkä tiedostot haluat säilyttää?",
"If you select both versions, the copied file will have a number added to its name." => "Jos valitset kummatkin versiot, kopioidun tiedoston nimeen lisätään numero.",
"Cancel" => "Peru",
"Continue" => "Jatka",
"(all selected)" => "(kaikki valittu)",
"({count} selected)" => "({count} valittu)",
"Error loading file exists template" => "Virhe ladatessa mallipohjaa",
"Very weak password" => "Erittäin heikko salasana",
"Weak password" => "Heikko salasana",
"So-so password" => "Kohtalainen salasana",
"Good password" => "Hyvä salasana",
"Strong password" => "Vahva salasana",
"Shared" => "Jaettu",
"Shared by {owner}" => "Jakanut {owner}",
"Shared with {recipients}" => "Jaettu henkilöiden {recipients} kanssa",
"Share" => "Jaa",
"Error" => "Virhe",
"Error while sharing" => "Virhe jaettaessa",
"Error while unsharing" => "Virhe jakoa peruttaessa",
"Error while changing permissions" => "Virhe oikeuksia muuttaessa",
"Shared with you and the group {group} by {owner}" => "Jaettu sinun ja ryhmän {group} kanssa käyttäjän {owner} toimesta",
"Shared with you by {owner}" => "Jaettu kanssasi käyttäjän {owner} toimesta",
"Share with user or group …" => "Jaa käyttäjän tai ryhmän kanssa…",
"Share link" => "Jaa linkki",
"The public link will expire no later than {days} days after it is created" => "Julkinen linkki vanhenee {days} päivän jälkeen sen luomisesta",
"By default the public link will expire after {days} days" => "Oletuksena julkinen linkki vanhenee {days} päivässä",
"Password protect" => "Suojaa salasanalla",
"Choose a password for the public link" => "Valitse salasana julkiselle linkille",
"Allow Public Upload" => "Salli julkinen lähetys",
"Email link to person" => "Lähetä linkki sähköpostitse",
"Send" => "Lähetä",
"Set expiration date" => "Aseta päättymispäivä",
"Expiration date" => "Päättymispäivä",
"Share via email:" => "Jaa sähköpostilla:",
"No people found" => "Henkilöitä ei löytynyt",
"group" => "ryhmä",
"Resharing is not allowed" => "Jakaminen uudelleen ei ole salittu",
"Shared in {item} with {user}" => "{item} on jaettu {user} kanssa",
"Unshare" => "Peru jakaminen",
"notify by email" => "ilmoita sähköpostitse",
"can share" => "jaa",
"can edit" => "voi muokata",
"access control" => "Pääsyn hallinta",
"create" => "luo",
"update" => "päivitä",
"delete" => "poista",
"Password protected" => "Salasanasuojattu",
"Error unsetting expiration date" => "Virhe purettaessa eräpäivää",
"Error setting expiration date" => "Virhe päättymispäivää asettaessa",
"Sending ..." => "Lähetetään...",
"Email sent" => "Sähköposti lähetetty",
"Warning" => "Varoitus",
"The object type is not specified." => "The object type is not specified.",
"Enter new" => "Kirjoita uusi",
"Delete" => "Poista",
"Add" => "Lisää",
"Edit tags" => "Muokkaa tunnisteita",
"Error loading dialog template: {error}" => "Virhe ladatessa keskustelupohja: {error}",
"No tags selected for deletion." => "Tunnisteita ei valittu poistettavaksi.",
"Updating {productName} to version {version}, this may take a while." => "Päivitetään {productName} versioon {version}, tämä saattaa kestää hetken.",
"Please reload the page." => "Päivitä sivu.",
"The update was unsuccessful." => "Päivitys epäonnistui.",
"The update was successful. Redirecting you to ownCloud now." => "Päivitys onnistui. Selain ohjautuu nyt ownCloudiisi.",
"%s password reset" => "%s salasanan nollaus",
"Use the following link to reset your password: {link}" => "Voit palauttaa salasanasi seuraavassa osoitteessa: {link}",
"You will receive a link to reset your password via Email." => "Saat sähköpostitse linkin nollataksesi salasanan.",
"Username" => "Käyttäjätunnus",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Tiedostosi on salattu. Jos et ole ottanut palautusavainta käyttöön, et voi käyttää tiedostojasi enää salasanan nollauksen jälkeen. Jos et ole varma mitä tehdä, ota yhteys ylläpitoon ennen kuin jatkat. Haluatko varmasti jatkaa?",
"Yes, I really want to reset my password now" => "Kyllä, haluan nollata salasanani nyt",
"Reset" => "Nollaa salasana",
"New password" => "Uusi salasana",
"New Password" => "Uusi salasana",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Mac OS X ei ole tuettu, joten %s ei toimi kunnolla tällä alustalla. Käytä omalla vastuulla!",
"For the best results, please consider using a GNU/Linux server instead." => "Käytä parhaan lopputuloksen saamiseksi GNU/Linux-palvelinta.",
"Personal" => "Henkilökohtainen",
"Users" => "Käyttäjät",
"Apps" => "Sovellukset",
"Admin" => "Ylläpito",
"Help" => "Ohje",
"Error loading tags" => "Virhe tunnisteita ladattaessa",
"Tag already exists" => "Tunniste on jo olemassa",
"Error deleting tag(s)" => "Virhe tunnisteita poistaessa",
"Error tagging" => "Tunnisteiden kirjoitusvirhe",
"Error untagging" => "Tunisteiden poisto virhe",
"Error favoriting" => "Suosituksen kirjoitusvirhe",
"Error unfavoriting" => "Suosituksen poisto virhe",
"Access forbidden" => "Pääsy estetty",
"Cloud not found" => "Pilveä ei löydy",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Hei sinä!\n\n%s jakoi kohteen %s kanssasi.\nTutustu siihen: %s\n\n",
"The share will expire on %s." => "Jakaminen päättyy %s.",
"Cheers!" => "Kippis!",
"Security Warning" => "Turvallisuusvaroitus",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "PHP-asennuksesi on haavoittuvainen NULL Byte -hyökkäykselle (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Päivitä PHP-asennus varmistaaksesi, että %s on turvallinen käyttää.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "Turvallista satunnaislukugeneraattoria ei ole käytettävissä, ota käyttöön PHP:n OpenSSL-laajennus",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Ilman turvallinen satunnaislukugeneraattori, hyökkääjä saattaa pystyä ennustamaan salasanan tunnuksineen ja ottaa tilisi.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Datakansiosi ja tiedostosi ovat mitä luultavimmin muiden saavutettavissa internetistä, koska .htaccess-tiedosto ei toimi.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "Lisätietoja palvelimen asetuksien määrittämisestä on saatavilla <a href=\"%s\" target=\"_blank\">dokumentaatiosta</a>.",
"Create an <strong>admin account</strong>" => "Luo <strong>ylläpitäjän tunnus</strong>",
"Password" => "Salasana",
"Storage & database" => "Tallennus ja tietokanta",
"Data folder" => "Datakansio",
"Configure the database" => "Muokkaa tietokantaa",
"Only %s is available." => "Vain %s on käytettävissä.",
"Database user" => "Tietokannan käyttäjä",
"Database password" => "Tietokannan salasana",
"Database name" => "Tietokannan nimi",
"Database tablespace" => "Tietokannan taulukkotila",
"Database host" => "Tietokantapalvelin",
"SQLite will be used as database. For larger installations we recommend to change this." => "SQLitea käytetään tietokantana. Laajoja asennuksia varten tämä asetus kannattaa muuttaa. ",
"Finish setup" => "Viimeistele asennus",
"Finishing …" => "Valmistellaan…",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "Tämä sovellus vaatii toimiakseen JavaScriptin käyttöä. <a href=\"http://enable-javascript.com/\" target=\"_blank\">Ota JavaScript käyttöön</a> ja päivitä tämä käyttöliittymä.",
"%s is available. Get more information on how to update." => "%s on saatavilla. Lue lisätietoja, miten päivitys asennetaan.",
"Log out" => "Kirjaudu ulos",
"Automatic logon rejected!" => "Automaattinen sisäänkirjautuminen hylättiin!",
"If you did not change your password recently, your account may be compromised!" => "Jos et vaihtanut salasanaasi äskettäin, tilisi saattaa olla murrettu.",
"Please change your password to secure your account again." => "Vaihda salasanasi suojataksesi tilisi uudelleen.",
"Server side authentication failed!" => "Palvelimen puoleinen tunnistautuminen epäonnistui!",
"Please contact your administrator." => "Ota yhteys ylläpitäjään.",
"Forgot your password? Reset it!" => "Unohditko salasanasi? Palauta se!",
"remember" => "muista",
"Log in" => "Kirjaudu sisään",
"Alternative Logins" => "Vaihtoehtoiset kirjautumiset",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Hei!<br><br>%s jakoi kanssasi kohteen <strong>%s</strong>.<br><a href=\"%s\">Tutustu siihen!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "Tämä ownCloud-asennus on parhaillaan single user -tilassa.",
"This means only administrators can use the instance." => "Se tarkoittaa, että vain ylläpitäjät voivat nyt käyttää tätä ownCloudia.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
"Thank you for your patience." => "Kiitos kärsivällisyydestäsi.",
"%s will be updated to version %s." => "%s päivitetään versioon %s.",
"The following apps will be disabled:" => "Seuraavat sovellukset poistetaan käytöstä:",
"The theme %s has been disabled." => "Teema %s on poistettu käytöstä.",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "Varmista ennen jatkamista, että tietokanta, asetuskansio ja datakansio on varmuuskopioitu.",
"Start update" => "Käynnistä päivitys",
"This ownCloud instance is currently being updated, which may take a while." => "Tätä ownCloud-asennusta päivitetään parhaillaan, siinä saattaa kestää hetki.",
"Please reload this page after a short time to continue using ownCloud." => "Päivitä tämä sivu hetken kuluttua jatkaaksesi ownCloudin käyttämistä.",
"File not found" => "Tiedostoa ei löytynyt",
"The specified document has not been found on the server." => "Määritettyä asiakirjaa ei löytynyt palvelimelta.",
"You can click here to return to %s." => "Napsauta tästä palataksesi %siin.",
"To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" => "Välttääksesi aikakatkaisuja suurikokoisten asennusten kanssa, voit suorittaa vaihtoehtoisesti seuraavan komennon asennushakemistossa:",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
